==> parrot-0.0.9.tar.gz: parrot-0.0.9/include/parrot/method_util.h <==
/* method_util.h
 *  Copyright: (When this is determined...it will go here)
 *  CVS Info
 *     $Id: method_util.h,v 1.4 2002/11/21 01:47:47 dan Exp $
 *  Overview:
 *     Utilities to help in writing methods.
 *  Data Structure and Algorithms:
 *  History:
 *     Initial revision by sean 2002/08/04 
 *  Notes:
 *  References:
 */

#if !defined(PARROT_METHOD_UTIL_H_GUARD)
#define PARROT_METHOD_UTIL_H_GUARD

#include "parrot/pmc.h"
#include "parrot/config.h"

void Parrot_push_argv(struct Parrot_Interp * interp, INTVAL argc, PMC * argv[]);
INTVAL Parrot_pop_argv(struct Parrot_Interp * interp, PMC *** argv);
void Parrot_push_proto(struct Parrot_Interp * interp,
                       INTVAL intc, INTVAL * intv,
                       INTVAL numc, FLOATVAL * numv,
                       INTVAL strc, STRING ** strv,
                       INTVAL pmcc, PMC ** pmcv);

typedef INTVAL (*Parrot_csub_t)(struct Parrot_Interp * , PMC * );
PMC * Parrot_new_csub(struct Parrot_Interp * interp, Parrot_csub_t func);
PMC * Parrot_new_nci(struct Parrot_Interp * interp, Parrot_csub_t func, String *signature);

struct method_rec_t {
    char * name;
    Parrot_csub_t sub;
};

void Parrot_init_stash(struct Parrot_Interp * interp, struct method_rec_t * recp,
                       struct Stash * stash);

PMC * Parrot_find_method(struct Parrot_Interp * interp, struct Stash * stash,
                         PMC * key);

PMC * mark_stack(struct Parrot_Interp *,
                 Stack_Chunk_t * cur_stack, PMC * end_of_used_list);

#endif /* PARROT_METHOD_UTIL_H_GUARD */

==> parrot-0.0.10.tar.gz: parrot-0.0.10/include/parrot/method_util.h <==
/* method_util.h
 *  Copyright: (When this is determined...it will go here)
 *  CVS Info
 *     $Id: method_util.h,v 1.7 2003/01/16 17:26:33 leo Exp $
 *  Overview:
 *     Utilities to help in writing methods.
 *  Data Structure and Algorithms:
 *  History:
 *     Initial revision by sean 2002/08/04
 *  Notes:
 *  References:
 */

#if !defined(PARROT_METHOD_UTIL_H_GUARD)
#define PARROT_METHOD_UTIL_H_GUARD

#include "parrot/pmc.h"
#include "parrot/config.h"

void Parrot_push_argv(struct Parrot_Interp * interp, INTVAL argc, PMC * argv[]);
INTVAL Parrot_pop_argv(struct Parrot_Interp * interp, PMC *** argv);
void Parrot_push_proto(struct Parrot_Interp * interp,
                       INTVAL intc, INTVAL * intv,
                       INTVAL numc, FLOATVAL * numv,
                       INTVAL strc, STRING ** strv,
                       INTVAL pmcc, PMC ** pmcv);

typedef INTVAL (*Parrot_csub_t)(struct Parrot_Interp * , PMC * );
PMC * Parrot_new_csub(struct Parrot_Interp * interp, Parrot_csub_t func);

struct method_rec_t {
    char * name;
    Parrot_csub_t sub;
};

void Parrot_init_stash(struct Parrot_Interp * interp, struct method_rec_t * recp,
                       struct Stash * stash);

PMC * Parrot_find_method(struct Parrot_Interp * interp, struct Stash * stash,
                         PMC * key);

void mark_stack(struct Parrot_Interp *, Stack_Chunk_t * cur_stack);

#endif /* PARROT_METHOD_UTIL_H_GUARD */

/*
 * Local variables:
 * c-indentation-style: bsd
 * c-basic-offset: 4
 * indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
